@@ -21,7 +21,7 @@ require AutoLoader;
 @EXPORT = qw(
 	
 );
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 my %EuroRates = (
          BEF => {EUR=>0.0247899055505,   BEF => 1},
@@ -70,15 +70,16 @@ sub setRate() {
 sub setRatesFile() {
 	my $self = shift;
 	$self->{RatesFile} = shift;
-	$self->readRatesFile();
 }
 
 sub readRatesFile() {
 	my $self = shift;
-	return if (!defined $self->{RatesFile});
+	if (!defined $self->{RatesFile} || !-r $self->{RatesFile} || !-s $self->{RatesFile} > 0) {
+		warn("Can't read $self->{RatesFile}\n");
+		return;
+	}
 
-	open(RATES, "<$self->{RatesFile}") or return;
-	$self->{CurrencyRates} = (); # clear current table
+	open(RATES, "<", $self->{RatesFile}) or { warn("Can't read $self->{RatesFile}\n") and return };
 	while(local $_ = <RATES>) {
 		my ($source, $targetrates) = split(/\|/, $_);
 		foreach my $target (split(/\:/, $targetrates)) {
@@ -95,7 +96,7 @@ sub writeRatesFile() {
 	my $self = shift;
 	return if (!defined $self->{RatesFile});
 
-	open(RATES, ">$self->{RatesFile}") or return;
+	open(RATES, ">", $self->{RatesFile}) or { warn("Can't access $self->{RatesFile}") and return };
 	foreach my $sourcerate (sort keys %{$self->{CurrencyRates}}) {
 		print RATES "$sourcerate|";
 		foreach my $targetrate (sort keys %{ $self->{CurrencyRates}{$sourcerate}}) {
@@ -118,7 +119,7 @@ sub _getQuoteFetcher() {
 	my $ecbAvailable = 0;
 	eval { require Finance::Quote::CurrencyRates::ECB; };
 	if ($@) {
-		warn "Finance::Quote::CurrencyRates::ECB not installed - probably no free rates available\n";
+		warn "Finance::Quote::CurrencyRates::ECB not installed\n";
 	} else {
 		$ecbAvailable = 1;
 	};
@@ -207,10 +208,11 @@ Convert currencies and fetch their exchange rates (with Finance::Quote)
    $amount_euro = $converter->convertToEUR(100, "DEM");
    $amount_dem = $converter->convertFromEUR(100, "DEM");
 
-   $converter->updateRates("EUR", "DEM", "USD");
-   $converter->updateRate("DEM", "USD");
+   $converter->updateRates("USD");
+   $amount_euro = $converter->convertToEUR(100, "USD");
 
    $converter->setRatesFile(".rates");
+   $converter->readRatesFile();
    $converter->writeRatesFile();
 
 
@@ -326,7 +328,7 @@ update the exchange rates in memory.
 
 	$converter->setUserAgent("MyCurrencyAgent 1.0");
 
-Set the user agent string to be used by Finance::Quote.
+Set the user agent string to be used by Finance::Quote, optional.
 
 =head2 SETRATE
 
@@ -339,16 +341,13 @@ but may be of use if you have to add a rate manually.
 
    $converter->setRatesFile(".rates");
 
-Name the file where exchange rates are stored. If it already exists
-it will be read into memory.
+Name the file where exchange rates are stored.
 
 =head2 READRATESFILE
 
    $converter->readRatesFile();
 
-Usually called internally by setRatesFile, but may also be called
-directly to revert to the rates stored in the file.
-Calling readRatesFile() will erase all existing exchange rates in memory.
+Read the rates stored in the rates file, overwriting previous values.
 
 =head2 WRITERATESFILE
 
